@@ -2,13 +2,13 @@ from configparser import ConfigParser, RawConfigParser
 from .file_storage import FileStorage
 from typing import Any
 from io import StringIO
-from .ini_section import IniSection, NoneIniSection
+from .ini_section import ActualIniSection, NoneIniSection
 
 
 class IniFile(FileStorage):
 
     parser: RawConfigParser
-    virtual_section: IniSection
+    virtual_section: ActualIniSection
 
     def __init__(self, path:str):
 
@@ -16,14 +16,14 @@ class IniFile(FileStorage):
         with open(path, 'r') as file:
             config_string = '[VIRTUAL_SECTION]\n' + file.read()            
             parser.read_string(config_string)
-        self.virtual_section = IniSection(parser, 'VIRTUAL_SECTION')
+        self.virtual_section = ActualIniSection(parser, 'VIRTUAL_SECTION')
 
         
     def __getattr__(self, attr_name: str) -> Any:
         if attr_name in self.virtual_section:
             return self.virtual_section.__getattr__(attr_name)
         elif attr_name in self.parser:
-            return IniSection(self.parser, attr_name)
+            return ActualIniSection(self.parser, attr_name)
         else:
             return NoneIniSection(self.parser, attr_name)
 
