@@ -7,7 +7,7 @@ class NodePromise:
         self.resource = resource
         self.node_id = node_id
 
-    def __get__(self, obj, objtype=None):
+    def __getattr__(self, obj, objtype=None):
         return self.resource.read(node_id=self.node_id)
 
 
@@ -17,6 +17,6 @@ class FieldPromise(NodePromise):
         self.field_name = field_name
         return super().__init__(resource, node_id)
 
-    def __get__(self, obj, objtype=None):
+    def __getattr__(self, obj, objtype=None):
         res = self.resource.read([self.field_name], node_id=self.node_id)
         return getattr(res, self.field_name)
\ No newline at end of file
